@@ -5,7 +5,7 @@ use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v2.0.0';
+our $VERSION = 'v2.0.1';
 
 use IO::Stream::const;
 use MIME::Base64;
@@ -109,7 +109,7 @@ IO::Stream::Proxy::HTTPS - HTTPS proxy plugin for IO::Stream
 
 =head1 VERSION
 
-This document describes IO::Stream::Proxy::HTTPS version v2.0.0
+This document describes IO::Stream::Proxy::HTTPS version v2.0.1
 
 
 =head1 SYNOPSIS
@@ -152,16 +152,21 @@ target {host} (and not when socket will connect to HTTPS proxy itself).
 
 =head1 INTERFACE 
 
-=over
+=head2 new
 
-=item new({ host=>$host, port=>$port })
-
-=item new({ host=>$host, port=>$port, user=>$user, pass=>$pass })
+    $plugin = IO::Stream::Proxy::HTTPS->new({
+        host=>$host,
+        port=>$port,
+    });
+    $plugin = IO::Stream::Proxy::HTTPS->new({
+        host=>$host,
+        port=>$port,
+        user=>$user,
+        pass=>$pass,
+    });
 
 Connect to proxy $host:$port, optionally using basic authorization.
 
-=back
-
 
 =head1 DIAGNOSTICS
 
@@ -237,7 +242,7 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2008 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2008- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
